package com.gyee.table.controller;

import com.alibaba.fastjson2.JSONObject;
import com.gyee.table.entity.Configurationinfo;
import com.gyee.table.result.Result;
import com.gyee.table.result.ResultCode;
import com.gyee.table.service.IConfigurationinfoService;
import com.gyee.table.utils.SnowflakeIdUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author hlf
 * @date 2023/3/20 10:03
 * 文件说明：
 */
@Slf4j
@RestController
@RequestMapping("/cic")
public class ComponentInformationController {

    @Resource
    private IConfigurationinfoService configurationinfoService;

    /**
     * 查询组件信息列表
     *
     * @return
     */
    @GetMapping("/componentList")
    public JSONObject componentList() {
        List<Configurationinfo> list = configurationinfoService.list();
        return Result.successData(ResultCode.SUCCESS, list);
    }

    /**
     * 新增组件信息
     *
     * @param configurationinfo
     * @return
     */
    @PostMapping("/addComponent")
    public JSONObject addComponent(@RequestBody Configurationinfo configurationinfo) {
        configurationinfo.setId(Long.toString(new SnowflakeIdUtils(1, 3).nextId()));
        configurationinfoService.save(configurationinfo);
        return Result.success();
    }

    /**
     * 修改组件信息
     *
     * @param configurationinfo
     * @return
     */
    @PostMapping("/updateComponent")
    public JSONObject updateComponent(@RequestBody Configurationinfo configurationinfo) {
        configurationinfoService.updateById(configurationinfo);
        return Result.success();
    }

    /**
     * 删除组件信息
     *
     * @param id
     * @return
     */
    @PostMapping("/deleteComponent")
    public JSONObject deleteComponent(@RequestParam(value = "id") String id) {
        configurationinfoService.removeById(id);
        return Result.success();
    }
}
